@@ -2,22 +2,22 @@
 # Copyright or Copr. INRIA/Scilab - Sylvestre LEDRU
 #
 # Sylvestre LEDRU - <sylvestre.ledru@inria.fr> <sylvestre@ledru.info>
-# 
-# This software is a computer program whose purpose is to generate C++ wrapper 
+#
+# This software is a computer program whose purpose is to generate C++ wrapper
 # for Java objects/methods.
-# 
+#
 # This software is governed by the CeCILL  license under French law and
-# abiding by the rules of distribution of free software.  You can  use, 
+# abiding by the rules of distribution of free software. You can  use,
 # modify and/ or redistribute the software under the terms of the CeCILL
 # license as circulated by CEA, CNRS and INRIA at the following URL
-# "http://www.cecill.info". 
-# 
+# "http://www.cecill.info".
+#
 # As a counterpart to the access to the source code and  rights to copy,
 # modify and redistribute granted by the license, users are provided only
 # with a limited warranty  and the software's author,  the holder of the
 # economic rights,  and the successive licensors  have only  limited
-# liability. 
-# 
+# liability.
+#
 # In this respect, the user's attention is drawn to the risks associated
 # with loading,  using,  modifying and/or developing or reproducing the
 # software by the user in light of its specific status of free software,
@@ -25,13 +25,13 @@
 # therefore means  that it is reserved for developers  and  experienced
 # professionals having in-depth computer knowledge. Users are therefore
 # encouraged to load and test the software's suitability as regards their
-# requirements in conditions enabling the security of their systems and/or 
-# data to be ensured and,  more generally, to use and operate it in the 
-# same conditions as regards security. 
-# 
+# requirements in conditions enabling the security of their systems and/or
+# data to be ensured and,  more generally, to use and operate it in the
+# same conditions as regards security.
+#
 # The fact that you are presently reading this means that you have had
 # knowledge of the CeCILL license and that you accept its terms.
-# 
+#
 # For more information, see the file COPYING
 
 from types import MethodType
@@ -41,7 +41,7 @@ class JNIFrameWork:
 	"""
 	This class provides the JNI code
 	"""
-	
+
 	__JavaVMVariable="jvm"
 	__JavaVMVariableType="JavaVM"
 
@@ -85,7 +85,7 @@ class JNIFrameWork:
 
 	def getJavaVMVariable(self):
 		return self.__JavaVMVariable
-	
+
 	def getJavaVMVariableType(self):
 		return self.__JavaVMVariableType
 
@@ -107,13 +107,12 @@ class JNIFrameWork:
 		return curEnv;
 		}"""%(objectName, error)
 
-	
+
 	def getObjectDestuctor(self,objectName,stringClassSet=False):
 		myStr="""
 		%s::~%s() {
 		JNIEnv * curEnv = NULL;
 		this->jvm->AttachCurrentThread(reinterpret_cast<void **>(&curEnv), NULL);
-		
 		curEnv->DeleteGlobalRef(this->instance);
 		curEnv->DeleteGlobalRef(this->instanceClass);
 		"""%(objectName, objectName)
@@ -136,7 +135,7 @@ class JNIFrameWork:
 		return myStr + """
 		}
 		}"""
-	
+
 	def getEndSynchronizeMethod(self,objectName):
 		myStr="""
 		void %s::endSynchronize() {
@@ -151,24 +150,35 @@ class JNIFrameWork:
 		return myStr + """
 		}
 		}"""
-	
+
         # For static methods, we can not call getCurrentEnv() because it is not static
 	def getStaticProfile(self):
-		return """
+		static = """
 		JNIEnv * curEnv = NULL;
 		jvm_->AttachCurrentThread(reinterpret_cast<void **>(&curEnv), NULL);
-		jclass cls = curEnv->FindClass( className().c_str() );
-		""" 
+		jclass cls = initClass(curEnv);
+		if ( cls == NULL) {
+		"""
+
+		# Management of the error
+		if configGiws().getThrowsException():
+			errorMgnt = """throw %s::JniCallMethodException(curEnv);""" % (configGiws().getExceptionFileName())
+		else:
+			errorMgnt = """std::cerr << "Could not access to the class " << className() << std::endl;
+			exit(EXIT_FAILURE);"""
+
+		return static + errorMgnt + """
+		}
+		"""
 
 	def getDeleteStaticProfile(self):
-		return """curEnv->DeleteLocalRef(cls);
-		"""
-	
+		return ""
+
 	def getObjectInstanceProfile(self):
 		return """
 		JNIEnv * curEnv = getCurrentEnv();
 		"""
-	
+
 	def getExceptionCheckProfile(self, detachThread, methodReturn=""):
 		if configGiws().getThrowsException():
 			str="""if (curEnv->ExceptionCheck()) {
@@ -194,11 +204,11 @@ class JNIFrameWork:
 			params+=parameter.getType().getTypeSignature()
 
 		methodIdName=method.getUniqueNameOfTheMethod()
-		
+
 		signatureReturn=method.getReturn().getTypeSignature()
-		if method.getReturn().isArray() and not method.getReturn().isByteBufferBased(): # Returns an array ... 
+		if method.getReturn().isArray() and not method.getReturn().isByteBufferBased(): # Returns an array ...
 			signatureReturn="["* method.getReturn().getDimensionArray() + signatureReturn
-		
+
                 if method.getModifier()=="static":
                         getMethod = "GetStaticMethodID"
                         firstParam = "cls"
@@ -206,7 +216,7 @@ class JNIFrameWork:
                         getMethod = "GetMethodID"
                         firstParam = "this->instanceClass"
 		if method.getModifier()=="static":
-			methodCall="jmethodID"
+			methodCall="static jmethodID"
 		else:
 			methodCall="""if (%s==NULL) { /* Use the cache */
 			"""%methodIdName
@@ -219,7 +229,7 @@ class JNIFrameWork:
 			curEnv->ExceptionDescribe();
 			%s
 			exit(EXIT_FAILURE);"""%(method.getName(),method.getDetachThread())
-			
+
 		methodIdProfile="""
 		%s %s = curEnv->%s(%s, "%s", "(%s)%s" ) ;
 		if (%s == NULL) {
@@ -227,7 +237,7 @@ class JNIFrameWork:
 		}
 		"""%(methodCall, methodIdName, getMethod, firstParam, method.getName(), params,signatureReturn, methodIdName, errorMgnt)
 		if method.getModifier()!="static":
-			methodIdProfile+="}" # Cached methodId 
+			methodIdProfile+="}" # Cached methodId
 		return methodIdProfile
 
 
@@ -236,19 +246,18 @@ class JNIFrameWork:
 		returnType=method.getReturn()
 		i=1
 		params=""
-		
+
 		for parameter in parametersTypes:
 			if i==1:
 				params+="," # in order to manage call without param
 			params+=parameter.getName()
 			if parameter.getType().specificPreProcessing(parameter,method.getDetachThread())!=None:
-				params+="_" # There is a pre-processing, then, we add the _ 
-			if len(parametersTypes)!=i: 
+				params+="_" # There is a pre-processing, then, we add the _
+			if len(parametersTypes)!=i:
 				params+=", "
 			i=i+1
-			
-			
-		if returnType.getNativeType()=="void": # Dealing with a void ... 
+
+		if returnType.getNativeType()=="void": # Dealing with a void ...
 			returns=""
 			returnsEnd=""
 		else:
@@ -264,10 +273,11 @@ class JNIFrameWork:
                         return """
                         %s curEnv->%s( this->instance, %s %s)%s;
                         """ % (returns, returnType.getCallMethod(), method.getUniqueNameOfTheMethod(), params, returnsEnd)
-		
+
+
 	def getReturnProfile(self, returnType):
 		return returnType.getReturnSyntax()
-		
+
 
         def getDLLExportSyntax(self):
                 return """
