@@ -64,6 +64,11 @@ int main(){
   	JavaVM* jvm = create_vm();
 	MyObject *plop = new MyObject(jvm);
 	cout << "A string from Java : " << plop->getMyString() <<endl;
+
+	if (plop->getMyStringNull()==NULL) {
+        cout << "plop->getMyStringNull() returned NULL" << endl;
+    }
+
 	plop->doNothingPleaseButDisplay(23);
 	cout << "Hashcode of my two strings " << plop->giveMeTheHashCodePlease(const_cast<char*>("plop"), const_cast<char*>("plop2")) << endl;
 	cout << "Inverse my boolean. True becomes : " << plop->workingWithBoolean(true) << endl << "False becomes : " << plop->workingWithBoolean(false) << endl;;
